@@ -8,6 +8,7 @@
 #' str_to_upper(dog)
 #' str_to_lower(dog)
 #' str_to_title(dog)
+#' str_to_sentence("the quick brown dog")
 #'
 #' # Locale matters!
 #' str_to_upper("i") # English
@@ -30,3 +31,11 @@ str_to_lower <- function(string, locale = "en") {
 str_to_title <- function(string, locale = "en") {
   stri_trans_totitle(string, opts_brkiter = stri_opts_brkiter(locale = locale))
 }
+#' @export
+#' @rdname case
+str_to_sentence <- function(string, locale = "en") {
+  stri_trans_totitle(
+    string,
+    opts_brkiter = stri_opts_brkiter(type = "sentence", locale = locale)
+  )
+}
