@@ -1,16 +1,16 @@
 #' Extract matched groups from a string.
 #'
-#' Vectorised over \code{string} and \code{pattern}.
+#' Vectorised over `string` and `pattern`.
 #'
 #' @inheritParams str_detect
 #' @param pattern Pattern to look for, as defined by an ICU regular
-#'   expression. See \link[stringi]{stringi-search-regex} for more details.
-#' @return For \code{str_match}, a character matrix. First column is the
+#'   expression. See [stringi::stringi-search-regex] for more details.
+#' @return For `str_match`, a character matrix. First column is the
 #'   complete match, followed by one column for each capture group.
-#'   For \code{str_match_all}, a list of character matrices.
+#'   For `str_match_all`, a list of character matrices.
 #'
-#' @seealso \code{\link{str_extract}} to extract the complete match,
-#'   \code{\link[stringi]{stri_match}} for the underlying
+#' @seealso [str_extract()] to extract the complete match,
+#'   [stringi::stri_match()] for the underlying
 #'   implementation.
 #' @export
 #' @examples
@@ -34,21 +34,26 @@
 #' str_extract(x, "<.*?>")
 #' str_extract_all(x, "<.*?>")
 str_match <- function(string, pattern) {
-  switch(type(pattern),
-    regex = stri_match_first_regex(string, pattern,
-      opts_regex = attr(pattern, "options")),
+  if (type(pattern) != "regex") {
     stop("Can only match regular expressions", call. = FALSE)
+  }
+
+  stri_match_first_regex(string,
+    pattern,
+    opts_regex = opts(pattern)
   )
 }
 
 #' @rdname str_match
 #' @export
 str_match_all <- function(string, pattern) {
-  switch(type(pattern),
-    regex = stri_match_all_regex(string, pattern,
-      cg_missing = "",
-      omit_no_match = TRUE,
-      opts_regex = attr(pattern, "options")),
+  if (type(pattern) != "regex") {
     stop("Can only match regular expressions", call. = FALSE)
+  }
+
+  stri_match_all_regex(string,
+    pattern,
+    omit_no_match = TRUE,
+    opts_regex = opts(pattern)
   )
 }
