@@ -6,6 +6,9 @@ test_that("basic subsetting for fixed patterns works", {
     str_subset(c("i", "I"), fixed("i", ignore_case = TRUE)),
     c("i", "I")
   )
+
+  # negation works
+  expect_equal(str_subset(c("i", "I"), fixed("i"), negate = TRUE), "I")
 })
 
 test_that("str_which is equivalent to grep", {
@@ -13,4 +16,10 @@ test_that("str_which is equivalent to grep", {
     str_which(head(letters), "[aeiou]"),
     grep("[aeiou]", head(letters))
   )
+
+  # negation works
+  expect_equal(
+    str_which(head(letters), "[aeiou]", negate = TRUE),
+    grep("[aeiou]", head(letters), invert = TRUE)
+  )
 })
